
# q-expansion of newform 25.14.a.d, downloaded from the LMFDB on 18 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 25
weight = 14
poly_data = [10385664, 125608, -17722, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, 1, 0, 0], 1], [[58416, -16570, 3, 1], 228], [[-8864, 9, 1, 0], 1]]

hecke_ring_character_values = None
aps_data = [[16, 1, 0, 0], [215, 1, 1, 0], [0, 0, 0, 0], [25454, 998, -66, 40], [1663987, 25885, 5685, 360], [1257068, -92012, 9900, -280], [12443845, 627112, 7152, -10440], [69984419, 2669557, -37755, -1936], [302749146, -2820210, -267906, 3600], [1914518336, -26000572, 1316940, 53496], [-3173200018, -19912270, 3392130, -32720], [9533380802, 12903900, 6971268, 772440], [-20322933763, 28588280, -11689320, 1738080], [24390009932, -361768676, -20180748, -3155800], [17386182868, 392710024, 9602016, -6125400], [-44866548410, -19749944, 3589416, 14562720], [-213739675928, -3002961704, 24861600, 14644152], [148187992082, -3714234500, -165391500, -1195000], [-171690680275, 1030521707, 49116867, -55918040], [239567534612, -8694886000, 119403000, -113265000], [-419566756669, -9961831760, 652429704, -36387160], [-90465473014, 4713401138, -953559030, -189947864], [2107901282169, -9925070073, 880459263, 235845000], [632654196903, -27398798856, -3575515680, 355430808], [3041509973858, -47737157736, -2938848024, -130067280], [1011798374862, -22900742580, 3491032020, 83616120], [4900523544260, 42442008576, 4515556296, -91026120], [6363384820659, 52242737253, -4271209971, 803096280], [-5786307823498, 152736547116, 166076340, 302072952], [-8827775561177, -66724029992, 2205592440, 411757920], [15363121983086, -371261419334, 11194008090, 3521255840], [37883115780972, 48705381060, -5732671140, 5546045160], [44175219536877, -332367923880, -32982812472, -1921204080], [-18814844755717, 38934925389, -8151170715, 2600725608], [-15012494796640, 31249244300, -19220628540, -9900277560], [-14082632162338, 1440652343470, -114225435930, -4787873080], [133082474024834, -88069248912, -46896909216, 7429416720], [133345794529733, 413855890083, -38071780725, 3407377560], [229273033286820, 1556224185192, 2587364592, 1890447480], [18494291623896, -1030996743720, 115277063064, 1927114560], [-290942900507609, -2875919090207, 38257828065, 48978245376], [317904684699842, 1308268680600, 350929788600, 13932741600], [258160579139282, -5317757032930, -456650535330, 6032387520], [-440325688323883, 1942871529384, -243083057808, 17313533880], [333659108803758, 5341245643584, 264544046736, 60621332400], [-94396010043220, 2511881894500, 158730637380, -97015936480], [-479464207888483, 3976923763395, -32204104005, -113835836280], [536504050937876, 2003950085820, -1098000889236, -86820995760], [750772698922316, -11321888985004, 683074518060, -14212370520], [1399895548220756, -9922603301992, 7361265000, -36069220304], [1714941564920454, 16120908221712, 1101043483728, -81931187520], [79954233696688, -6450742056356, -1480818017820, 30395632248], [-1674344422760503, 4638311946400, -755667336600, 256694665400], [585394367410077, 17414954857275, -990843106725, -346423629600], [-976881105751026, -6244133103912, -3970749764376, -370313007120], [-1719534110372662, -19280809011322, 3865414014390, -360267125040], [-4214938718498096, 19323492686752, -1893062253360, -486123284016], [-2010156154289698, -40655570495870, -593327329470, -146130992320], [-5769005510423344, 34301723793236, 1421950828620, 565848469000], [4074423313907982, 6909063459480, -4489532544120, 268194923280], [-2664588012224131, -2274935633053, 3663364919523, 321594474880], [1712790079530102, 47413017384564, -7323286560708, -717036962760], [-1422924816573481, 123400232097913, -8258724134631, 608999512160], [4520144235849522, 14801392173330, 9196396628730, 151582745880], [3238467971136698, -150227936234472, 3657510429000, 722491362000], [20517129454472060, 46708733378552, -1716368291688, -386432457120], [-7305048425937313, -38555505709135, 1976179273065, 472103805640], [3149116091969507, 181008418296520, 26743225000008, -444646917760], [31254433069370563, -295954858463651, 1962551438661, -2091544796520], [-13464739235778490, -111675834558860, -2187653911620, 1459254870200], [-6649530284550330, 206136587200296, -4037812442184, 1512259743600], [-35822153088992238, -151917530998014, 15541775872410, -1281637490328], [-12085668591218740, -339566364349588, -30730759038708, 1987787847520], [-41060934132666454, -74230226600, -34094167465176, -1093321297360], [6026108749462001, 228458779608703, 8065746411855, -98801550544], [44250287510465754, 156666953613402, 9793495708098, 4255064812440], [-37983173035725042, 345063253655664, -7351653333840, -1188278678592], [-5309425233877852, -698261734784096, 33218906847936, 4662336508640], [28332400427682357, 231717572001960, -19208805378240, 8683063747560], [-851046860917243, -217791859266864, -15255633645120, -12594309681648], [31267003276399319, -396276732305263, 37771063921185, 1514225391984], [-11823107345159548, 114028896096280, 43227110188680, -2997691703920], [-63229232380366878, -883544377544190, -26931895896390, 1220643641160], [-32754953407781851, 1268163796902472, -8287538602272, 6026361204200], [64052315183436728, -321549131226236, -70859159437620, 18617163618488], [23568554900602737, 328795561749399, -77034067491993, -16686046633680], [-38767142743107815, 201621800076760, -54257626272960, 9086994656280], [-102720089598920431, 1073710212443968, 58041252179184, -5025383980720], [93636679115346492, -443235236618280, -388430044680, 716118685920], [-53517116248953532, -1641446000421292, -88564516476540, 21848622101200], [-61148711028237940, 1682340371463932, 32852126942052, 24545493048600], [88522307418314946, 941362530937638, -197778488159370, 2135238073776], [-29413446671692978, 1542434315407530, -161963532190422, -11262600908160], [-249708068557869508, -739296684131260, -82470573675060, -18177896772360], [194718610985683460, -3215358139232180, 81847730623620, -21808681322680], [230141828869659020, 1905632285264036, -141661701140364, 23615912838960], [136212005449938802, 341820908461696, -57210288141120, 33885594459072], [-188939913870974323, 4460336308678880, -170057619558720, 30810484507680], [544090302067977671, -533083781879735, 81111082943169, 24862975022600], [426263944289374352, 1087950397505960, 412590303410760, 46135812926560], [303044065929318743, -2763874422775751, 41896220304441, -76612375456000], [-418023905142365796, 3404117807799708, 319291403017764, 7438421276280], [166024932980207568, -123196196342832, -82321142953560, 3205140310440], [-428542622132501151, 1855653181585152, 430993552870560, -74451637957536], [-122645690814251068, -6123850185271260, -30904787721060, 4033298693640], [89905845460670051, -4032435277023864, -113920729105560, 93371227080480], [-61929364626256983, 3869744688664215, 95464958049303, 76689608549760], [-1009505220931312873, 4249370174744744, 273726912890232, 7546537888560], [569744610259877810, -5826816782480710, -219473654739870, -104286189465000], [425215449648641627, -11940613163436600, -320054048457600, -122342318124600], [798511222270630064, -2804017454458712, -443698630835736, -15220241911360], [-564858685877115442, -1215922044655472, -97175251171440, 44098652176640], [-416576443158690930, 7477334107256832, -331996491506688, -34177839759360], [-405623531854782316, 1812363654474732, -484071180978540, 150977691672024], [-124498547213103298, -3219708277809830, 639921339013770, 129679425191120], [-21770538622347318, -7852852492609080, -1096779057489480, 64765025007120], [2001805144672347452, -1858974781465876, 48380663035572, -18697166594120], [610991503847710468, 5543248962120844, -849866512123524, 59900475736080], [-531462058857679690, -5369020774344844, -1792174014472164, 38532391277400], [1280659029625502977, -2094880256569649, 101623028909895, -29333852182008], [1580278601299123472, 13896087616262380, -1003061030690220, -28145968841320], [-802935509973659014, 13208233259353760, 152892991254144, -243672654203360], [-415973085338955984, 1449887809476936, 725123932517880, -102856741533360], [1493445450834330279, -3054223311568743, 1513173929933313, 197926906791960], [557241749160316007, 13417335341538145, 1387288233335745, -189077911005280], [-7018500185902708, -5106622555603420, 1460604905107980, 168936115961880], [-371644902476394028, 11172929325606376, 3330328308321240, 68554190150672], [-1364178531884003346, 31928501173259742, -613625421916890, 244299547650744], [-1627319890135105024, -6581841077982084, 1441191787596180, -493315717503000], [-3200421904949212276, 6115422684128052, 494165334274668, -279549180826680], [2568385986338172068, -11430938171595596, -750341617545060, -268238998335592], [169646979313620922, -44781297161590226, -2090090045265858, -195303693108240], [-4434179244044309008, 27997131582505180, 224996632976580, 134340782099480], [-3345872498011823536, -20202517717615832, -624905246031096, 327740100380960], [3631009742654862717, 18565421473038120, 1351304836419720, 379021125820320], [-2154664598035741171, -43699013265483048, -1565414219772960, 260279243364984], [3858519512486054856, 55544253795750660, 56285492312364, -240040379747880], [-2656992700635531628, -68523120265787060, 1965467293167108, 446115309742280], [5167731124061466938, 36030435973360064, 1590275519249856, -578843973250560], [-1286604220443390718, 13215167023137416, -3345418286147880, 183929610954672], [2417172674772960452, -72395432031049660, -2994762895523460, 327321424423240], [-1054770465343959078, 63350510821306920, 3858254004614520, 305469366675120], [-3884872228740437884, -33187667211961740, -3253955830014876, 633913991711760], [5785790816572710601, 89846000413373911, 3402434095657815, -301090822830720], [-1828333959902654284, 24530549532100148, 6662593710287580, -320547051931304], [-631579511822116432, 51299420495823824, 1765025510539200, 130226012233488], [-5126493959229499510, -64742682394984264, -2830344819573144, 56781510441040], [4761478311838806349, -110117236052770592, -4021728407210016, -510406037303040], [-5117559092566421893, -53081174452984499, 4192064504168325, -181169717666488], [-40844684949179992, 110545874025686828, 937795124058660, 383043946661640], [473204962725529076, 10406856077418296, 2242898222534520, 639166059133120], [4320627390589568782, -40360893763576520, -2378106400632120, -395732388600720], [-9576053068058258401, -65819499722653983, -1587156741762687, -419610216508320], [5890744022704941492, -139830563523424500, 1776272597589708, 190275979867200], [3898080498499282724, 18419189052055268, 7762385680096764, -825604292034200], [12411932695428443812, -53353234838421740, -1003758208724940, -1970771439428640], [-17842818472647849766, 50084452215633742, -11130068719368210, -1385719668101536], [3735636008213514206, 180906126574313648, -9814885570472880, 717035538293856], [11538769516298558987, 42563865505501400, -18841492778755872, 1339520659721080], [-877111671691232548, 211868370244065260, -349407893168940, 98793273294360], [-3151407872522707512, -50486159040748056, -18492822237871104, -498919187519640], [23970238499259021385, -42336122439194864, 8079773600816976, 1237495789725120], [-5624625611501789200, -44398022545162488, -7285307873178168, -2525740700176320], [-13410443286210342333, -14941645475431515, 2314383050076285, -1551304830686040], [3573728713488694801, -90132242859533384, 2653110453846480, -1154677507925400], [-12017194081836225606, 150321879727626042, -15715751307064542, 663913612206360], [29346904590738899882, -33682905462300030, -3722780587769430, -69135345079080], [2499106978133607188, -253283908008422896, 4311080863135776, 2840212386857200], [-3575367635487603043, 57176134584839256, -12418042213876560, 928628202325032], [3371613934320425288, 74339391329110028, -21803885538460860, 2336046616361160], [-17415973531221583431, -16591895110388193, 23043733467902895, -2755099167432336], [-10070927178793658158, -26422123017898340, -1049646016770540, -2625223910245240], [-513502683081032718, -28881283807499670, 11847077687177730, 3034966165355880], [-1980282607767426541, -154763254994503048, -11179985814465072, -1609416539508440], [5730768696963225128, 456900080019505084, 28850469323044740, 565462156307768], [43817145061031140695, -346025288284183800, -12935486553667680, -3878098188151320], [-11704077120429105883, -14270183365313245, 290945272513155, 595464218219680], [-26224563704639226018, -238843788895964700, -9367032571307700, 2769055456987800], [-19487530956220648792, -272986121351296752, -3203226603182880, 187420196739120], [6089921059753149074, 267754652203377952, 17983528785460560, 2296455277306064], [-11355277425691278628, 101176498409247900, -11901682685005812, 181861585445520], [-22510207493718381793, -150435320575207855, 2395018959383745, 1611360409464720], [30193476876626507582, 238232186410351204, -29643864648660708, 3943551972789320], [-24267335889865592137, -343564506264923776, 12517150456413336, 5889234303256680], [5407149801533440620, 73245806134285896, -21095261047109184, -8283207795406200], [62724485736132198292, 25645142489920096, 16491486192459120, -1947258768369168], [11724011667952038770, -78380938157252668, -10927263788291988, -7965430063995560], [-30253817545071199189, -371994650055183995, 1483462080911829, -4935115424768080], [-4796539367543334679, 79916845721905968, -18257535731102880, -6347723294144304], [-11409931537152100448, 682044739273218700, 3148321323527700, 4566720617710200], [-26589048004202977105, -228222388760966624, -381426081817344, 2374190481900320], [-25260982079104387547, -226867594445695877, 8224265137921515, 10876483188090000], [12119128093722104237, 233924174680677275, -55951414281931725, 922093704135400], [-23126188120205929298, 578520503647942120, -64713985883984280, -2095747263607680], [8554397531914082907, 116393314822335165, 43635922275230493, -5019993502109280], [30619822895404290602, 1173482212971630704, -52263676843866288, -970665292735200], [50116837514376837107, -119378459659499840, 69442749168588960, 5132002096969760], [-22169108126329688182, -390940118412944392, 80744839171082760, -1681154195382800], [75447479283614999355, -53124210631064328, -88998603031140408, 2405634230222640], [77308398290722008266, 256874481545099450, 8715100985424594, 10997415379590120], [-29811691138968874014, -1228252358269476432, -34210372852062240, 3621937063989456], [58937027422208777612, -642710808270415060, 17517311114944140, -4454696063896160], [17578192050595945232, 713193060324086600, -21173149447902552, 2379942084384160], [-20605527684902348845, -335304055630288040, 37619007045260760, -3684865972781440], [2474208440995678692, 118607211588518076, -12110749276920540, -11314982967171048], [144667855506590840826, 762016950485452776, 11525558901565560, -6848634326063760], [38240465556458206046, 1004590582333094898, 16574330734259010, 5889526206826416], [158251286913366266164, 476290482024628012, 38973771160078788, -6899578769600280], [40344183610755286878, 1265880186638502384, 57355538078894640, -10225118236180032], [-71343015325143363928, -703609449681057000, -108952906586808000, -985769409561000], [-80608114013764122622, 20848722613364544, 25216839617425536, -22016660579446080], [72106988602195070522, -878096274083233660, -18078042035117460, -17961433307510760], [10137900372514803920, -524060015980817284, -45115950563472924, 19422604025328280], [71445509555861445079, 563595518554853233, -30730048224295911, -9959893525230120], [-28146184712184192306, -1998398313553078158, -17554328807406750, 5553721024191504], [72282876794379972737, 31210735526271000, -9711982321851000, 13732383497658000], [70019065986684863966, 404145791464760866, -28792182922152030, 17747155962911360], [30933377726738630997, -1075831155785015520, -27370959011952120, -5128794359343720], [83144207001668463410, 849281090867663162, -55178281363692558, -14826873763901880], [-19927644882947333694, 1977275360181826020, 110751753017899644, -8705302214687640], [-64739415598367590498, -42642533578163480, -204047405451161880, -11355449489985280], [-62184756826041254020, 1627957064473811640, 179056239404646000, 4655579993476680], [84921690833525748297, -1240081915035708384, 245438873495669160, 10311416185898232], [14598694656354300386, 39969343759611010, -72511590168349206, 3624481987961240], [309051860231345050031, 106280008056637241, 89773980871790985, -16756812291347280], [167300503016788054886, 1085347371425369508, 5412326469043980, -32087871840321384], [25538878050182296239, -2615515716932662248, -50858106613341792, 9846162120831480], [69804725145341119568, 1351842035954902844, 117785406998764260, 23033019926650968], [-61691598880448629972, -1104693628425151376, 12093892631062776, 18558243089074040], [-204175659152557125543, 252716534553426735, 340320847126103535, -20770928436623040], [-63922871993902934230, 579811081199640956, -16035009123422604, -26381141310938360], [241710260074541536217, -1167427539619592009, 153712039748781855, 29673200063775512], [-16097093829170113378, 3375997800479465670, 179484045168336270, 24052341985752120], [8451238274559610087, -645608445782069360, 41929189137546840, -358061075301960], [221116562831957444264, 3512072905358837832, -154456529445115152, 3292011516221400], [288931240160928028482, 221058688364800650, -118859312254069902, -21491134613009640], [-130053327293391339187, -1584128804281338856, -239685212818384320, 17002466341436248], [-139024157748259156888, -3634356983981368396, -64411781491814628, -14212495656576360], [195150016343787338325, -2362078428756110925, 262103413867992675, -4731224134100400], [-133244547998838837708, 622672428929656020, -182886108394588380, -16703410664627280], [223092481443520495551, -1960199494798623375, 273863090709369729, 13078149009266160], [-101100847168675019623, -1998866312383782505, 237102702088027095, 29182216240112320], [59976591489611812502, -6441855447859849886, 368632029390763842, 23351484935947040], [-495376916700520299820, -2333205646203428680, -27951396656288760, 19269594297434800], [10257057623588667555, 490394442206414136, 351191948105062296, -18533571809320800], [121969569006427922752, 5821012193803554856, -125048848094026440, -44235434059542288], [725799900343954255130, 3252879054330803442, 47303166477944202, -20928232915817880], [-575570287486135028, -6320699387779788980, 178272658194049620, -14734223112230280], [-62508074447937582799, -4262496001124679057, -423951131163348225, 9701382289244016], [70791211741453278184, -1904812050428173268, -185300307764271132, -65255701451668920], [-269311419972358647952, -2993584711037037056, -606939776061945744, -21673389549574000], [8941913111301198427, -469744236465218000, -469776473613582000, 58855366947276000], [510060092864428702194, -7658591763974360502, 347470464285395874, -6329140371725400], [-591864321081054910933, -2478660502723084504, 60661759911114720, -10022684641446968], [248144231515595984888, 1656230194858965788, 222663864791590020, 10958688587208600], [1064893220328788163489, -822414109268072433, 46769683187787495, 21106048526582184], [600038290343942931632, -3539386982969054660, -453079204875818460, -2108011521366760], [357964795049785477601, 4787282990501957871, 20431119686480895, -18837340309470480], [490025549170301054322, -6265029247464644940, -322041711082930932, -1793683888631640], [-2627592520202332651, -4426779959242814832, -341059689364321536, 3892924935392400], [699038326537885433858, 4221147980922544858, 1590932391320850, -75223718816086840], [-565311810044586062635, 2451594761198610707, 308199369493999707, 55362848017848120], [386898669882854804024, -621875567282478828, 548508436137987420, -23514911278838856], [388869449458778479772, 2155878462046696844, 101020071023596452, 82437763337150440], [-26189498836257524667, 696784956497966784, -497561825770351464, 71552117613465000], [-80701060159026899425, 4512790500125448865, -89228465957275455, 110050660486542560], [598323267897284558302, 9261795380260275136, -145041259544974800, -50900439310336368], [671280044960733991982, 6052233705311328440, -126895383862722360, -106190264801990160], [-465629847980701036009, 783416004413088825, -296868034232686431, 78754176713162520], [70798374953067959914, 12507661025430861532, -700408666658666652, 42679584393031800], [-185814485535807827548, 3125625439830179460, -146068881206326740, 72130049281513560], [-361230850867650294127, -13694428421603551001, 461543262876141471, 49867594542059720], [-127502946434048143105, -5223818141248756464, 252079576244864136, -158523462717314040], [-388954076878681378888, -5948672949670379884, 513300210523563900, -76597570018840808], [984695674024202545346, -9879461979361715584, -421228337003769600, -80234624179118720], [-785445383614214353516, 13866078915518311452, -143906040375221172, 85729060518782160], [-1995856076648797563273, 723332682925839225, 118367030170451793, 18885294578422440], [-309455617529656832152, -1547830544979783976, 230907073241554680, 164714488493571808], [-339165615324822503458, -328735838101677520, -551159955099099120, -11498226336650720], [-1102374773972604303993, -6225517943687444775, 666755233653399225, -60126673161650400], [-357136428527208412804, -15121687939378130980, -852637627944608916, 83969447262660720], [689769059338171239722, 9957423784355993110, 64543455853859910, 91060720506698960], [1796890547469374520008, -1904321177930392336, 404880103435350576, 61421978972905920], [-706826478675324842908, 1621489719004567520, -797764590704090880, -195848753243029280], [-1619237618699900777755, 4772835439112269307, 324815318852951787, -53055592668715760], [-1811795219433121848, -7350553491558944520, -747750728813688120, -31834225195200720], [268713075385874000606, -16629189391848672080, -857529585436631856, 41902617893128160], [-793967130292184326944, -3043873385798317044, 552449091004850580, -161512515799875720], [-408297552445058492704, -5781340121050854432, 580065608378765520, 112927676547284496], [-103178044680344998302, 4039151274105246144, -584150827803303360, 120301404294665088], [-361278166629139564918, -10100766879619386340, 257597374646651460, 58260151488236760], [-1389965339455174089076, 2600821605778906868, -1049313920601037236, -249944373999063000], [573837573262303916643, 4831674396829244328, 1263061135756041120, -76785509167584120], [1054782498444514861197, -18967131487666383165, -534907358347006365, 69474490469278560], [566397314610674587244, 7575902494183134312, 639269737337275368, 54908509418835840], [-521788986253109161650, -11747113800796973160, 1154182660808466120, -196781006911195440], [365923546875862243502, 8888019210291410550, -493532365852638450, -226875635009602200], [-453334399754286150984, -27397850685629915100, -2641471078634219556, -37381233312145080], [-645403709897128791924, 11310363915814356348, 657450118940398740, 222215190880997736], [-798934923814846145143, 3231103631089230375, 4355510183167023, -357483249329391240], [1101848641964689288217, 7608173423801261864, -748141634814117768, 190963457224001200], [-545891663767650912002, -36004202619577597076, 234521522404416996, -35528232311209080], [-1571647388887559549920, 28545072818747197960, 1028820712050295560, 133662056578549760], [-2553378132120654777405, 915113867658397461, 1471492704206211861, -79458998590679040], [-1758602447126694343723, -3603146043686500085, -1252598722205088885, -48130967101298560], [-1218357433531201261975, 19108746337385122872, -1266938374476990288, 89897821686502920], [629162852417376072156, 18782820551224213836, -455256064163099580, 130373952777707400], [117113775512275499846, 22670728127982812148, 217523701504008060, -16608023319765384], [-1949072633206475256162, 12705839572386587754, -1501027309382155590, -147959997376402512], [228923736084386982110, 2469783971795533796, 2026335356692274556, 90807955033101160], [1646235968714363409498, 36433121940212375178, 28680977476559250, 18729354569527800], [-2017457398127441982606, -2803984600497796608, 707143557566181600, 269432206274313504], [761129026888659468777, 29541992992615506120, -1319632910004047280, 295272015315043320], [1534782585437262038744, -15652709645140345848, -1120406469501818112, -133173890369767800], [3158840189831062276292, 2435081922615805940, -1541384338417071372, -17456288614410240], [454125184095735348278, -1998671340728504456, -2224116796542135480, -81271733010480592], [-1300002233910633105885, -40106302748582752275, -1961560260603544035, -89189285166523440], [5047694640641340757032, -5585131802334194400, -743576691831962400, -29735840087582400], [2716092922202727635663, -15145127827120221112, 634266661837653720, -179728313777440400], [-1697220621890147014989, -22207396780681747752, 931807817845168200, 511249207431071376], [-1033008672861058933228, 11896013879001861660, 1091140466764841460, -260186949303537240], [745908402155670265517, 41730280333270048800, 150641150757901008, 100208537289042000], [2908188382530966944092, -37642339290272071460, -612594309727975260, -400163042978575560], [-1185485499142631268778, -14241471018729261686, 1073905953208841562, 262405669000739120], [-112601117146435904310, -18487791304938764184, 2293529370973702296, 328382758515998160], [3493128980835511988162, 3567914011592491960, 1641209182486718760, 154637161936380560], [-657586379336574891379, 27541232894700433803, 1577472409394634675, -170716811891633064], [-2156183425752071364820, -19892100386525922524, 149358177923942316, 190818358898541560], [1558523004721498343334, -25960209290219859402, 4301016482212498014, -85642386844812840], [-4646236184989514157212, 7630491305089464148, -120116036438254500, -492620272707204360], [-1761068747718426441148, 7583021945694194780, -281134309260131820, -66002381437908920], [-2428922990709568475078, -11086007621446984820, -2518848273713644572, -54487026403023960], [-1102452636324847059622, -62311846235779497126, 665359263693578610, -311671133506165272], [-2752684784281219061293, 1592092620524007869, 2284914908846099037, -526583081048303520], [-4662785126127246775153, -12660420432200800335, -3126282243601944135, -345410615905447560], [-3211405383850538803240, 15321862293386664392, 4947675931663730832, -15412868375436360], [-2832205626954054038536, 32154916386208195572, -1126265616263491140, 404506961783899704], [-4618514567682786326014, 13153526570529612320, 167212868009089824, -510759148971813120], [616053745032169629287, 47206817578034571240, 1492168796095339440, -121131400650444360], [2707090644900602486222, -34031014015668304810, 1018499601319850958, -211676447502483320], [2796838885281424858472, -46954715410118230496, 2939887466253331632, 596937360988768880], [-6463240619092853483647, -15090557802466475056, -4592753497157537664, -268195823731036080], [-1477089957122574524898, 15390388668958134456, -3032302970753492040, -1245487181503039488], [3587503827439730573252, 20769864714981324440, 6722875625235830640, 459285179565388840], [-4276092002190252339386, 38313932335536940792, 1607743221166970328, 551548837373444640], [8248168755097298158428, -37554320347468972356, -1265072540296014780, -329400440972867592], [4178602355601136196372, 106444277694137646300, -469749231948176700, -575482803619156200], [-3430504123983741314827, 54352253747981332219, -1285052345702733669, 522260226941621600], [-4651530296044884896208, 5669473664471433180, -3396511018639137420, 416362394848389480], [-6360612123107582841106, 9167835846006138548, 2900345032489031724, -77904840463457400], [-10083019166259308691943, 42948017138047812815, 2835329688637941015, 355727608696630840], [-3264744574076320218334, 6977444236990434776, -2699992971882953400, -434153544307794800], [1982551184620096673582, 42960865744814677580, 832044434344888980, 266923440894557880], [6078189517114317176804, 47589771896651787952, -4155006109435394952, -219082525703529160], [4699731656448760495058, 5925193612171202264, 357570472389505560, -12063347594441792], [-6500264185703314904133, 51450638504452194504, -979101642228092448, -76972766770943640], [-623424866400967172980, -38871594764337609880, -3693226748256666720, -1285971019043536440], [-2291176028228443624353, 53714942447440905105, -5301166728048183495, 327299233160888280], [-5807842361271630914130, 73924696240886656992, 5025580396196757792, 678820917375794880], [-902956634182518515564, 63968734098179361460, -907564965739106556, 1210235368786680240], [-1736499029312641512718, -98209752880210816460, -4187651323469868132, 339415007810861720], [22644058546034378347, -84784526843075087600, -2745264418456962600, -1003676188336086600], [2738760399308658048738, 51939785878731701994, -3058690547042237454, -157169926778482440], [4799678392061210876812, -66912551705265795644, 8752783457515667820, 846680613624193752], [-8722557654494406994495, 6432778192022222847, -5250251862855712233, -998688461039473560], [-4662689886775399196749, -9433076157161268080, -11274035155678884936, -523778831262472360], [-7042727696559246203784, 20150707276075359996, 4038113606247011460, -534811293090358920], [3327377326507111693880, -31166661797006790544, 8795289551360889456, 522052428724545280], [9351915695158720299077, -50577676559307733320, -2973130081656964920, 176658285783786480], [-3303041449241267389908, -74945176886657041500, 3964165193166685500, 634363205988609000], [1648520350076416087403, -125763850126720647691, -1331500200131316435, 598206459473149768], [6631917986795726617492, -46451538537151417556, -9339348458531564628, 1140385172519733120], [-617849428491004505460, -59292190001894625960, -595556932258184040, -2052819461130799680], [-9860600539926594551968, -63793769973444652840, 2898173208415893960, -151455476803136240], [4897946975491387756694, 63981005244424471588, 3291652069476858444, -434802246550118440], [8176912942323699027211, 112666101568671319213, 6198135532792428045, -443115383740877664], [3788588785227006930582, -76589807430681338730, 11457734618780265870, 254442268520307720], [-6469990530893542668133, 12147567284072453424, -3732052598437970688, 971273679545909040], [-8969345680022900132343, -121562279152965047424, -2463310180107917400, 110239713727975512], [2204654435164028627330, -23309251605528849248, 1769950943078428032, 122859276536118560], [7325343796303676113802, 47149418481448843280, -1335431954521108320, -474371731419307920], [-4293535575233102870031, -138290368445412773568, 8526558033945797328, -1029688044441947280], [6437007611531984318168, -3079659605373555356, -4043600957287269924, 2220862781886867080], [-402205022255788249561, -41645482458537498952, 5229616406677494744, 506991405661210080], [12748164279138248549312, -44912138818566843904, 733009556516642040, -1241515402970970488], [-977765343020316744002, -66955977909979925762, 8972819983047437430, 1479726497675804040], [8792780599658676913712, 113035861900821156600, -13621028606604287400, 1068335457566109600], [1603794342659073447776, 26803415743637135856, -5526278292294764400, -296368255609633440], [-22506444860313113430256, -41067206454526271488, -12053666684996407032, -548625480083252360], [12342595721532652239222, 176966882944554617970, 14498578631818232898, -495165445246530000], [-1039589675227119282757, 32877936607613460944, 5605667115565155360, -335533532573252432], [-1610530977140627583548, 245280836598262647304, -9574121931691614888, 977116454096871600], [-3055329323056970271275, 164363528098816527115, -14052114718282610805, -479425642793619840], [-13373274664277739099751, -9728539230769739097, -3311013788136308481, 62296874984652840], [12395800385827852435222, 29122828248722521330, -2196667834660614270, 1867786147253504880], [2066554026370165570733, -39646979447954955912, 6311638188834242040, 886594715514622080], [-10495726013193715020196, -19482919227840574308, -11029397000240539140, -400910879062901856], [-3095010163482019155039, 3613340104777238568, 13632536260968714360, 1590949785779495856], [-6512342046139501301173, 144759682555668234445, -1227972943126076955, -687273845030275480], [-4129990963999156561518, 90708505492278775920, -4413709567734672480, -2256947756111864880], [5932083667107673878920, -114995393810456487260, -258283604784659460, 40928074490608040], [-1262499303339269330955, -93180093626242079064, 2338413948440492736, -2166124488008082840], [8727810571707835121300, -230811623694312400928, -9362445819347289288, -1154671970739662680], [10124946751127885101001, -71379339079951811824, 8354163482854024560, 152321063672219040], [6249344440956790168688, -214470742534356425896, 7224571694821321560, -1059603360134867712], [1201956498220957907672, -178583786406374198300, -3313785031715835300, -668865296773415800], [-11556117648184154599822, -159672921882847687056, -3096713519555224464, -690066871729313280], [4581650847190158943562, 131395348157822030120, 5018627951821965720, -932540544178861680], [10746669797366023452860, 65832480095598608996, -710835169078127844, -1504251577497610040], [14209755083587378630869, -71459849501267759133, -8180437239554461125, 2340307415965547304], [23581100723302211558159, 183237332162172125432, -13697052507531957432, 499065653283855280], [19095544003805507102352, 154987286372920566960, -5424804230995221552, -1262105583743826720], [11374471148935666670497, 10520258536148543959, -2924927595316033353, 1643916712078144800], [-12711506897646637090348, -91060010058353803300, -10233695082460140300, 845441926489604200], [12119941519499102927519, -6890595947316416352, 7371934853241522024, -1049255927339901000], [-10976512059649173273098, 58963737400059273940, 8059646841400450140, -684603210145889160], [-17486938459614318698974, 91919845251249228878, -13908456123336329970, -2261150474967255744], [-12083986887559935312658, 103726845555690606850, -15236300222756924142, -4728981898639306000], [-16477577517327099492447, 44847977683510480464, -19384801779783528504, 894784526142510600], [10854591639728979520250, -99782498884937753614, 16241903216630176266, -190855722751332120], [10541315897421086028992, 19957082972488343156, 11830762200048241500, -1486585698133085928], [-11230520465898618776290, -150851105818345238228, -71088303789225228, 6081518461592143160], [15061745951568222185646, -355847878615773196854, -394998661872669510, -653566949627612400], [-6377722703257213285367, -6249180025902972401, -27664372644473051985, -2140831265980385952], [-22715801994280244950075, 418613615044015039416, 4131707873612137656, 3895147880741299200], [6821833204453883541664, 254564234711513324908, 27774063319224827124, 344222409247699320], [-11252709042503854986952, -204223389279036740632, 17340167597199873120, 897936087871850760], [30873362305663017756099, -119234880411030869568, 3176520967612325400, 3628985882035046184], [39981381260098494526847, -404200493379756507255, -9431577586707536655, -2876751733557544680], [-32416636534992481412990, -196611655716616217330, 24335310534399811470, -431677919867518080]]
